@@ -49,5 +49,5 @@ def test_export(export_path):
     Then: Expected export file exists.
     """
     export(valid_workflow_package, export_path)
-    path = export_path / Path("valid_workflow_dev.py")
+    path = export_path / Path("test-data_to_valid_core_dev.py")
     assert path.exists()
